Index: trunk/XTIDE_Universal_BIOS/Src/Device/IDE/IdePioBlock.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS/Src/Device/IDE/IdePioBlock.asm	(revision 488)
+++ trunk/XTIDE_Universal_BIOS/Src/Device/IDE/IdePioBlock.asm	(revision 489)
@@ -217,5 +217,7 @@
 ALIGN JUMP_ALIGN
 %ifdef USE_186
+%ifdef MODULE_8BIT_IDE
 IdePioBlock_ReadFromXtideRev2:
+%endif
 %endif
 IdePioBlock_ReadFrom16bitDataPort:
Index: trunk/XTIDE_Universal_BIOS/Src/Device/IDE/IdeWait.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS/Src/Device/IDE/IdeWait.asm	(revision 488)
+++ trunk/XTIDE_Universal_BIOS/Src/Device/IDE/IdeWait.asm	(revision 489)
@@ -93,5 +93,5 @@
 ;		AL, BX, CX, DX
 ;--------------------------------------------------------------------
-IdePollBsyAndFlgInAH:
+.IdePollBsyAndFlgInAH:
 	call	IdeIO_InputStatusRegisterToAL		; Discard contents of first read
 
Index: trunk/XTIDE_Universal_BIOS/Src/Device/Serial/SerialCommand.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS/Src/Device/Serial/SerialCommand.asm	(revision 488)
+++ trunk/XTIDE_Universal_BIOS/Src/Device/Serial/SerialCommand.asm	(revision 489)
@@ -66,7 +66,11 @@
 		mov		dx, [di+DPT_SERIAL.wSerialPortAndBaud]
 
+; fall through to SerialCommand_FallThroughToSerialServer_SendReceive
+		
 ALIGN JUMP_ALIGN
-SerialCommand_FallThroughToSerialServer_SendReceive:
+SerialCommand_FallThroughToSerialServer_SendReceive:		
 
+; fall through to SerialServer_SendReceive
+		
 %include "SerialServer.asm"
 
@@ -177,6 +181,10 @@
 .identifyDeviceInDX:
 
+; fall through to SerialCommand_FallThroughToSerialServerScan_ScanForServer
+		
 ALIGN JUMP_ALIGN
-SerialCommand_FallThroughToSerialServerScan_ScanForServer:		
+SerialCommand_FallThroughToSerialServerScan_ScanForServer:
+
+; fall through to SerialServerScan_ScanForServer
 		
 %include "SerialServerScan.asm"
Index: trunk/XTIDE_Universal_BIOS/Src/Handlers/Int13h/AH0h_HReset.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS/Src/Handlers/Int13h/AH0h_HReset.asm	(revision 488)
+++ trunk/XTIDE_Universal_BIOS/Src/Handlers/Int13h/AH0h_HReset.asm	(revision 489)
@@ -174,4 +174,4 @@
 
 .done:
-NoForeignDrivesToReset:
+.NoForeignDrivesToReset:
 	ret
Index: trunk/XTIDE_Universal_BIOS/Src/Initialization/DetectPrint.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS/Src/Initialization/DetectPrint.asm	(revision 488)
+++ trunk/XTIDE_Universal_BIOS/Src/Initialization/DetectPrint.asm	(revision 489)
@@ -50,25 +50,4 @@
 
 ;--------------------------------------------------------------------
-; Prints BIOS name and segment address where it is found.
-;
-; DetectPrint_RomFoundAtSegment
-;	Parameters:
-;		Nothing
-;	Returns:
-;		Nothing
-;	Corrupts registers:
-;		AX, SI, DI
-;--------------------------------------------------------------------
-DetectPrint_RomFoundAtSegment:
-	push	bp
-	mov		bp, sp
-	mov		si, g_szRomAt
-	ePUSH_T	ax, ROMVARS.szTitle			; Bios title string
-	push	cs							; BIOS segment
-
-	jmp		DetectPrint_FormatCSSIfromParamsInSSBP
-
-
-;--------------------------------------------------------------------
 ; DetectPrint_StartDetectWithMasterOrSlaveStringInCXandIdeVarsInCSBP
 ;	Parameters:
@@ -82,5 +61,5 @@
 DetectPrint_StartDetectWithMasterOrSlaveStringInCXandIdeVarsInCSBP:
 	mov		ax, [cs:bp+IDEVARS.wBasePort]   ; for IDE: AX=port address, DH=.bDevice
-	; Fall to DetectPrint_StartDetectWithAutodetectedBasePortInAX
+	; fall through to DetectPrint_StartDetectWithAutodetectedBasePortInAXandIdeVarsInCSBP
 
 ;--------------------------------------------------------------------
@@ -167,18 +146,52 @@
 ;		Nothing
 ;	Corrupts registers:
-;		AX, SI
+;		AX, SI, DI
 ;--------------------------------------------------------------------
 DetectPrint_DriveNameFromDrvDetectInfoInESBX:
-	push	di
-	push	bx
-
-	lea		si, [bx+DRVDETECTINFO.szDrvName]
-	mov		bx, es
-	CALL_DISPLAY_LIBRARY PrintNullTerminatedStringFromBXSI
-	CALL_DISPLAY_LIBRARY PrintNewlineCharacters
-
-	pop		bx
-	pop		di
-	ret
+	push	bp
+	mov		bp,sp	
+	lea		si,[bx+DRVDETECTINFO.szDrvName]
+	push	si
+	mov		si,g_szDriveName
+	jmp		SHORT DetectPrint_FormatCSSIfromParamsInSSBP
+
+				
+;--------------------------------------------------------------------
+; Prints BIOS name and segment address where it is found.
+;
+; DetectPrint_RomFoundAtSegment
+;	Parameters:
+;		Nothing
+;	Returns:
+;		Nothing
+;	Corrupts registers:
+;		AX, SI, DI
+;--------------------------------------------------------------------
+DetectPrint_RomFoundAtSegment:
+	mov		si, g_szRomAt
+	mov		di, cs						; BIOS segment address, for later inclusion in the output, parameterized
+										; so that it can be a different value when using .BootMenuEntry
+
+.BootMenuEntry:	
+	push	bp
+	mov		bp, sp
+
+%ifndef USE_186
+	mov		ax, ROMVARS.szTitle
+	push	ax
+	push	di							; BIOS segment
+	add		al, ROMVARS.szVersion - ROMVARS.szTitle
+	push	ax
+%else
+	; szTitle and szVersion have the high order byte of their addresses zero, 
+	; so these push instructions are only 2 bytes
+	;
+	push	ROMVARS.szTitle
+	push	di							; BIOS segment
+	push	ROMVARS.szVersion
+%endif
+
+	jmp		SHORT DetectPrint_FormatCSSIfromParamsInSSBP
+
 
 ;--------------------------------------------------------------------
Index: trunk/XTIDE_Universal_BIOS/Src/Initialization/Interrupts.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS/Src/Initialization/Interrupts.asm	(revision 488)
+++ trunk/XTIDE_Universal_BIOS/Src/Initialization/Interrupts.asm	(revision 489)
@@ -43,5 +43,5 @@
 %ifndef MODULE_HOTKEYS
 	cmp		BYTE [RAMVARS.bDrvCnt], 0
-	je		SHORT Interrupts_Return
+	je		SHORT Interrupts_InstallHandlerToVectorInALFromCSSI.Interrupts_Return
 %endif
 	; Fall to .InitializeInt13hAnd40h
@@ -172,5 +172,5 @@
 	mov		[es:bx], si				; Store offset
 	mov		[es:bx+2], cs			; Store segment
-Interrupts_Return:
+.Interrupts_Return:
 	ret
 
Index: trunk/XTIDE_Universal_BIOS/Src/Main.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS/Src/Main.asm	(revision 488)
+++ trunk/XTIDE_Universal_BIOS/Src/Main.asm	(revision 489)
@@ -88,6 +88,6 @@
 	at	ROMVARS.bIdleTimeout,	db	0						; Standby timer disabled by default
 
-	at	ROMVARS.ideVars0+IDEVARS.wBasePort,			dw	DEVICE_ATA_PRIMARY_PORT 		; Controller Command Block base port
-	at	ROMVARS.ideVars0+IDEVARS.wControlBlockPort,	dw	DEVICE_ATA_PRIMARY_PORTCTRL 	; Controller Control Block base port
+	at	ROMVARS.ideVars0+IDEVARS.wBasePort,			dw	300h 		; Controller Command Block base port
+	at	ROMVARS.ideVars0+IDEVARS.wControlBlockPort,	dw	310h 	; Controller Control Block base port
 	at	ROMVARS.ideVars0+IDEVARS.bDevice,			db	DEVICE_16BIT_ATA
 	at	ROMVARS.ideVars0+IDEVARS.bIRQ,				db	0
Index: trunk/XTIDE_Universal_BIOS/Src/Menus/BootMenu/BootMenuEvent.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS/Src/Menus/BootMenu/BootMenuEvent.asm	(revision 488)
+++ trunk/XTIDE_Universal_BIOS/Src/Menus/BootMenu/BootMenuEvent.asm	(revision 489)
@@ -37,5 +37,5 @@
 	eCMOVZ	dl, dh
 	call	IsDriveDLinSystem
-	jnc		SHORT DoNotSetDefaultMenuitem
+	jnc		SHORT BootMenuEvent_Handler.DoNotSetDefaultMenuitem
 	call	DriveXlate_SetDriveToSwap
 	; Fall to GetMenuitemToDXforDriveInDL
@@ -106,6 +106,6 @@
 	jmp		bx
 
-EventNotHandled:
-DoNotSetDefaultMenuitem:
+.EventNotHandled:
+.DoNotSetDefaultMenuitem:
 	xor		dx, dx		; Clear CF (and menuitem index for DoNotSetDefaultMenuitem)
 	ret
@@ -127,9 +127,9 @@
 
 	cmp		bx, BYTE MENUEVENT.RefreshItemFromCX	; Above last supported item?
-	ja		SHORT EventNotHandled
+	ja		SHORT .EventNotHandled
 	jmp		[cs:bx+rgfnEventSpecificHandlers]
 
-EventNotHandled:
-DoNotSetDefaultMenuitem:
+.EventNotHandled:
+.DoNotSetDefaultMenuitem:
 	xor		dx, dx		; Clear CF (and menuitem index for DoNotSetDefaultMenuitem)
 	ret
Index: trunk/XTIDE_Universal_BIOS/Src/Menus/BootMenu/BootMenuPrint.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS/Src/Menus/BootMenu/BootMenuPrint.asm	(revision 488)
+++ trunk/XTIDE_Universal_BIOS/Src/Menus/BootMenu/BootMenuPrint.asm	(revision 489)
@@ -76,11 +76,9 @@
 ;--------------------------------------------------------------------
 BootMenuPrint_TitleStrings:
-	mov		si, ROMVARS.szTitle
-	call	DetectPrint_NullTerminatedStringFromCSSIandSetCF
-	CALL_DISPLAY_LIBRARY PrintNewlineCharacters
-	mov		si, ROMVARS.szVersion
-	jmp		DetectPrint_NullTerminatedStringFromCSSIandSetCF
-
-
+	xor		di,di						; Null character will be eaten 
+	mov		si, g_szBootMenuTitle
+	jmp		DetectPrint_RomFoundAtSegment.BootMenuEntry
+
+		
 ;--------------------------------------------------------------------
 ; BootMenuPrint_RefreshInformation
Index: trunk/XTIDE_Universal_BIOS/Src/Strings.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS/Src/Strings.asm	(revision 488)
+++ trunk/XTIDE_Universal_BIOS/Src/Strings.asm	(revision 489)
@@ -27,7 +27,14 @@
 ; POST drive detection strings
 g_szDashForZero:	db	"- ",NULL	; Required by Display Library
-g_szRomAt:			db	LF,CR,"%s @ %x",LF,CR
-					db  "Released under GNU GPL v2",LF,CR,LF,CR,NULL
-
+g_szRomAt:			db	LF,CR
+					db	"%s @ %x",LF,CR						; -=XTIDE ... =- @ Segment
+					db	"%s",LF,CR							; version string 
+					db  "Released under GNU GPL v2",LF,CR	
+					db	LF,CR,NULL
+%ifdef MODULE_BOOT_MENU
+g_szBootMenuTitle:	db	"%s%c",LF,CR						; -=XTIDE ... =- and null (eaten)
+					db	"%s",NULL							; version string
+%endif
+g_szDriveName:		db	"%z",LF,CR,NULL
 
 ; The following strings are used by DetectPrint_StartDetectWithMasterOrSlaveStringInCXandIdeVarsInCSBP
@@ -166,5 +173,4 @@
 
 g_szSelectionTimeout:	db		DOUBLE_BOTTOM_LEFT_CORNER,DOUBLE_LEFT_HORIZONTAL_TO_SINGLE_VERTICAL,"%ASelection in %2-u s",NULL
-
 
 
Index: trunk/XTIDE_Universal_BIOS/Src/VariablesAndDPTs/BootVars.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS/Src/VariablesAndDPTs/BootVars.asm	(revision 488)
+++ trunk/XTIDE_Universal_BIOS/Src/VariablesAndDPTs/BootVars.asm	(revision 489)
@@ -50,4 +50,6 @@
 	mov		dl, [cs:ROMVARS.bBootDrv]
 
+	; fall through to BootVars_StoreHotkeyForDriveNumberInDL
+
 ;--------------------------------------------------------------------
 ; BootVars_StoreHotkeyForDriveNumberInDL
Index: trunk/XTIDE_Universal_BIOS/Src/VariablesAndDPTs/FindDPT.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS/Src/VariablesAndDPTs/FindDPT.asm	(revision 488)
+++ trunk/XTIDE_Universal_BIOS/Src/VariablesAndDPTs/FindDPT.asm	(revision 489)
@@ -246,6 +246,8 @@
 ;		SI
 ;--------------------------------------------------------------------
-ALIGN JUMP_ALIGN
-FindDPT_ToDSDIforFlagsHighInBL:
+%ifdef MODULE_IRQ		
+ALIGN JUMP_ALIGN
+FindDPT_ToDSDIforFlagsHighInBL:	
+%endif
 	mov		si, IterateToDptWithFlagsHighInBL
 	; Fall to IterateAllDPTs
Index: trunk/XTIDE_Universal_BIOS/Src/VariablesAndDPTs/RamVars.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS/Src/VariablesAndDPTs/RamVars.asm	(revision 488)
+++ trunk/XTIDE_Universal_BIOS/Src/VariablesAndDPTs/RamVars.asm	(revision 489)
@@ -229,4 +229,5 @@
 
 
+%if 0							; unused...
 ;--------------------------------------------------------------------
 ; RamVars_IsDriveDetectionInProgress
@@ -241,2 +242,3 @@
 	cmp		WORD [RAMVARS.wSignature], RAMVARS_DRV_DETECT_SIGNATURE
 	ret
+%endif
Index: trunk/XTIDE_Universal_BIOS/makefile
===================================================================
--- trunk/XTIDE_Universal_BIOS/makefile	(revision 488)
+++ trunk/XTIDE_Universal_BIOS/makefile	(revision 489)
@@ -108,4 +108,6 @@
 DEFINES_386_8K = $(DEFINES_AT) USE_386
 
+DEFINES_ALL_FEATURES = MODULE_8BIT_IDE MODULE_ADVANCED_ATA MODULE_BOOT_MENU MODULE_EBIOS MODULE_HOTKEYS MODULE_IRQ MODULE_SERIAL MODULE_SERIAL_FLOPPY MODULE_STRINGS_COMPRESSED MODULE_FEATURE_SETS 
+
 
 ###################
@@ -126,4 +128,5 @@
 DEFS_XT_TINY = $(DEFINES_XT_TINY:%=-D%) -DROMSIZE=$(ROMSIZE)
 DEFS_386_8K = $(DEFINES_386_8K:%=-D%) -DROMSIZE=$(ROMSIZE)
+DEFS_ALL_FEATURES = $(DEFINES_ALL_FEATURES:%=-D%)
 
 # Add -I in front of all header directories
@@ -222,6 +225,25 @@
 	@perl ..\tools\checksum.pl $(TARGET)_386.bin $(ROMSIZE)
 
-xt_unused: xt
-	@$(AS) "$(SRC_ASM)" $(ASFLAGS) $(DEFS_XT) -o"$(TARGET)_xt_unused.asm" -E -DCHECK_FOR_UNUSED_ENTRYPOINTS
-	@perl ..\tools\unused.pl $(TARGET)_xt.lst $(TARGET)_xt_unused.asm
-
+unused: 
+	@echo "All Features"
+	@$(AS) "$(SRC_ASM)" $(ASFLAGS) $(DEFS_ALL_FEATURES) $(DEFS_XT) $(DEFS_XT_PLUS) $(DEFS_AT) $(DEFS_XT_LARGE) $(DEFS_XTPLUS_LARGE) $(DEFS_AT_LARGE) $(DEFS_XT_TINY) $(DEFS_386_8K) -o"$(TARGET)_unused.asm" -l"$(TARGET)_unused.lst"
+	@$(AS) "$(SRC_ASM)" $(ASFLAGS) $(DEFS_ALL_FEATURES) $(DEFS_XT) $(DEFS_XT_PLUS) $(DEFS_AT) $(DEFS_XT_LARGE) $(DEFS_XTPLUS_LARGE) $(DEFS_AT_LARGE) $(DEFS_XT_TINY) $(DEFS_386_8K) -o"$(TARGET)_unused.asm" -E -DCHECK_FOR_UNUSED_ENTRYPOINTS
+	@perl ..\tools\unused.pl $(TARGET)_unused.lst $(TARGET)_unused.asm
+	@echo "XT Small"
+	@$(AS) "$(SRC_ASM)" $(ASFLAGS) $(DEFS_XT) -o"$(TARGET)_unused_xt.asm" -l"$(TARGET)_unused_xt.lst"
+	@$(AS) "$(SRC_ASM)" $(ASFLAGS) $(DEFS_XT) -o"$(TARGET)_unused_xt.asm" -E -DCHECK_FOR_UNUSED_ENTRYPOINTS
+	@perl ..\tools\unused.pl $(TARGET)_unused_xt.lst $(TARGET)_unused_xt.asm
+	@echo "XT Large"
+	@$(AS) "$(SRC_ASM)" $(ASFLAGS) $(DEFS_XT_LARGE) -o"$(TARGET)_unused_xtl.asm" -l"$(TARGET)_unused_xtl.lst"
+	@$(AS) "$(SRC_ASM)" $(ASFLAGS) $(DEFS_XT_LARGE) -o"$(TARGET)_unused_xtl.asm" -E -DCHECK_FOR_UNUSED_ENTRYPOINTS
+	@perl ..\tools\unused.pl $(TARGET)_unused_xtl.lst $(TARGET)_unused_xtl.asm
+	@echo "AT Small"
+	@$(AS) "$(SRC_ASM)" $(ASFLAGS) $(DEFS_AT) -o"$(TARGET)_unused_at.asm" -l"$(TARGET)_unused_at.lst"
+	@$(AS) "$(SRC_ASM)" $(ASFLAGS) $(DEFS_AT) -o"$(TARGET)_unused_at.asm" -E -DCHECK_FOR_UNUSED_ENTRYPOINTS
+	@perl ..\tools\unused.pl $(TARGET)_unused_at.lst $(TARGET)_unused_at.asm
+	@echo "AT Large"
+	@$(AS) "$(SRC_ASM)" $(ASFLAGS) $(DEFS_AT_LARGE) -o"$(TARGET)_unused_atl.asm" -l"$(TARGET)_unused_atl.lst"
+	@$(AS) "$(SRC_ASM)" $(ASFLAGS) $(DEFS_AT_LARGE) -o"$(TARGET)_unused_atl.asm" -E -DCHECK_FOR_UNUSED_ENTRYPOINTS
+	@perl ..\tools\unused.pl $(TARGET)_unused_atl.lst $(TARGET)_unused_atl.asm
+
+

Index: trunk/XTIDE_Universal_BIOS/Src/StringsCompressed.asm
===================================================================
--- trunk/XTIDE_Universal_BIOS/Src/StringsCompressed.asm	(revision 488)
+++ trunk/XTIDE_Universal_BIOS/Src/StringsCompressed.asm	(revision 489)
@@ -40,12 +40,37 @@
                 	  db	 28h,  00h          ; compressed
 
-g_szRomAt:			; db	LF,CR,"%s @ %x",LF,CR
-          			; db	 0ah,  0dh,  25h,  73h,  20h,  40h,  20h,  25h,  78h,  0ah,  0dh    ; uncompressed
-          			  db	 39h,  3dh,  20h, 0c6h,  37h,  39h                                  ; compressed
-
-	; db  "Released under GNU GPL v2",LF,CR,LF,CR,NULL
-	; db   52h,  65h,  6ch,  65h,  61h,  73h,  65h,  64h,  20h,  75h,  6eh,  64h,  65h,  72h,  20h,  47h,  4eh,  55h,  20h,  47h,  50h,  4ch,  20h,  76h,  32h,  0ah,  0dh,  0ah,  0dh,  00h    ; uncompressed
-	  db   58h,  6bh,  72h,  6bh,  67h,  79h,  6bh, 0eah,  7bh,  74h,  6ah,  6bh, 0f8h,  4dh,  54h, 0dbh,  4dh,  56h, 0d2h,  7ch,  2ch,  39h,  19h                                              ; compressed
-
+g_szRomAt:			; db	LF,CR
+          			; db	 0ah,  0dh    ; uncompressed
+          			  db	 39h          ; compressed
+
+	; db	"%s @ %x",LF,CR						; -=XTIDE ... =- @ Segment
+	; db	 25h,  73h,  20h,  40h,  20h,  25h,  78h,  0ah,  0dh    ; uncompressed
+	  db	 3dh,  20h, 0c6h,  37h,  39h                            ; compressed
+
+	; db	"%s",LF,CR							; version string 
+	; db	 25h,  73h,  0ah,  0dh    ; uncompressed
+	  db	 3dh,  39h                ; compressed
+
+	; db  "Released under GNU GPL v2",LF,CR	
+	; db   52h,  65h,  6ch,  65h,  61h,  73h,  65h,  64h,  20h,  75h,  6eh,  64h,  65h,  72h,  20h,  47h,  4eh,  55h,  20h,  47h,  50h,  4ch,  20h,  76h,  32h,  0ah,  0dh    ; uncompressed
+	  db   58h,  6bh,  72h,  6bh,  67h,  79h,  6bh, 0eah,  7bh,  74h,  6ah,  6bh, 0f8h,  4dh,  54h, 0dbh,  4dh,  56h, 0d2h,  7ch,  2ch,  39h                                  ; compressed
+
+	; db	LF,CR,NULL
+	; db	 0ah,  0dh,  00h    ; uncompressed
+	  db	 19h                ; compressed
+
+%ifdef MODULE_BOOT_MENU
+g_szBootMenuTitle:	; db	"%s%c",LF,CR						; -=XTIDE ... =- and null (eaten)
+                  	; db	 25h,  73h,  25h,  63h,  0ah,  0dh    ; uncompressed
+                  	  db	 3dh,  3ch,  39h                      ; compressed
+
+	; db	"%s",NULL							; version string
+	; db	 25h,  73h,  00h    ; uncompressed
+	  db	 1dh                ; compressed
+
+%endif
+g_szDriveName:		; db	"%z",LF,CR,NULL
+              		; db	 25h,  7ah,  0ah,  0dh,  00h    ; uncompressed
+              		  db	 3eh,  19h                      ; compressed
 
 
@@ -295,5 +320,4 @@
                      	; db		0c8h, 0b5h,  25h,  41h,  53h,  65h,  6ch,  65h,  63h,  74h,  69h,  6fh,  6eh,  20h,  69h,  6eh,  20h,  25h,  32h,  2dh,  75h,  20h,  73h,  00h    ; uncompressed
                      	  db		 31h,  32h,  3bh,  59h,  6bh,  72h,  6bh,  69h,  7ah,  6fh,  75h, 0f4h,  6fh, 0f4h,  3ah,  20h, 0b9h                                              ; compressed
-
 
 
@@ -530,11 +554,11 @@
 ;; 5-u:2
 ;; x:5
-;; s:13
+;; s:16
 ;; 5-x:1
-;; nl:9
+;; nl:12
 ;; 2-I:1
 ;; u:6
-;; c:9
-;; z:1
+;; c:10
+;; z:2
 ;; total format: 11
 